@@ -34,13 +34,17 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
         image_wrapper = BytesIO()
         # if file is png, jpg, or jpeg - rotate
         if ext in ['png', 'jpg', 'jpeg']:
-            image = Image.open(infile)
-            # Remove alpha channel for JPEG images
-            if ext in ['jpg', 'jpeg']:
-                image = image.convert('RGB')
+            try:
+                image = Image.open(infile)
+                # Remove alpha channel for JPEG images
+                if ext in ['jpg', 'jpeg']:
+                    image = image.convert('RGB')
 
-            transposed_image = ImageOps.exif_transpose(image)
-            transposed_image.save(image_wrapper, ('JPEG' if ext == 'jpg' else ext))
+                transposed_image = ImageOps.exif_transpose(image)
+                transposed_image.save(image_wrapper, ('JPEG' if ext == 'jpg' else ext))
+            except:
+                logger.info('Possible corrupted image, failed transposing it.')
+                logger.info(f'Offending file: {file_path}/{file_name}')
         else:
             image_wrapper = infile
 
